==> shadowsocks_1.0.3.tar.gz: shadowsocks/scripts/ss_rule_update.sh <==
#!/bin/sh
eval `dbus export ss`
source /koolshare/scripts/base.sh
alias echo_date='echo $(date +%Y年%m月%d日\ %X):'

start_update(){
	url_back="https://koolshare.ngrok.wang/maintain_files"
	url_main="https://raw.githubusercontent.com/koolshare/koolshare.github.io/acelan_softcenter_ui/maintain_files/"
	# version dectet
	version_gfwlist1=$(cat /koolshare/ss/rules/version | sed -n 1p | sed 's/ /\n/g'| sed -n 1p)
	version_chnroute1=$(cat /koolshare/ss/rules/version | sed -n 2p | sed 's/ /\n/g'| sed -n 1p)
	version_cdn1=$(cat /koolshare/ss/rules/version | sed -n 4p | sed 's/ /\n/g'| sed -n 1p)
	version_Routing1=$(cat /koolshare/ss/rules/version | sed -n 5p | sed 's/ /\n/g'| sed -n 1p)
	version_WhiteList1=$(cat /koolshare/ss/rules/version | sed -n 7p | sed 's/ /\n/g'| sed -n 1p)
	
	echo ==================================================================================================
	echo_date 开始更新shadowsocks规则，请等待...
	wget --no-check-certificate --timeout=8 -qO - "$url_back"/version1 > /tmp/version1
	if [ "$?" == "0" ]; then
		echo_date 检测到在线版本文件，继续...
	else
		echo_date 没有检测到在线版本，可能是访问github有问题，去大陆白名单模式试试吧！
		rm -rf /tmp/version1
		exit
	fi
	
	online_content=$(cat /tmp/version1)
	if [ -z "$online_content" ];then
		rm -rf /tmp/version1
	fi
	
	git_line1=$(cat /tmp/version1 | sed -n 1p)
	git_line2=$(cat /tmp/version1 | sed -n 2p)
	git_line4=$(cat /tmp/version1 | sed -n 4p)
	git_line5=$(cat /tmp/version1 | sed -n 5p)
	git_line7=$(cat /tmp/version1 | sed -n 7p)
	
	version_gfwlist2=$(echo $git_line1 | sed 's/ /\n/g'| sed -n 1p)
	version_chnroute2=$(echo $git_line2 | sed 's/ /\n/g'| sed -n 1p)
	version_cdn2=$(echo $git_line4 | sed 's/ /\n/g'| sed -n 1p)
	version_Routing2=$(echo $git_line5 | sed 's/ /\n/g'| sed -n 1p)
	version_WhiteList2=$(echo $git_line7 | sed 's/ /\n/g'| sed -n 1p)
	
	md5sum_gfwlist2=$(echo $git_line1 | sed 's/ /\n/g'| tail -n 2 | head -n 1)
	md5sum_chnroute2=$(echo $git_line2 | sed 's/ /\n/g'| tail -n 2 | head -n 1)
	md5sum_cdn2=$(echo $git_line4 | sed 's/ /\n/g'| tail -n 2 | head -n 1)
	md5sum_Routing2=$(echo $git_line5 | sed 's/ /\n/g'| tail -n 2 | head -n 1)
	md5sum_WhiteList2=$(echo $git_line7 | sed 's/ /\n/g'| tail -n 2 | head -n 1)
	
	# update gfwlist
	if [ "$ss_basic_gfwlist_update" == "1" ];then
		echo_date " ------------------------------------------------------------------------"
		if [ ! -z "$version_gfwlist2" ];then
			if [ "$version_gfwlist1" != "$version_gfwlist2" ];then
				echo_date 检测到新版本gfwlist，开始更新...
				echo_date 下载gfwlist到临时文件...
				wget --no-check-certificate --timeout=8 -qO - "$url_main"/gfwlist.conf > /tmp/gfwlist.conf
				md5sum_gfwlist1=$(md5sum /tmp/gfwlist.conf | sed 's/ /\n/g'| sed -n 1p)
				if [ "$md5sum_gfwlist1"x = "$md5sum_gfwlist2"x ];then
					echo_date 下载完成，校验通过，将临时文件覆盖到原始gfwlist文件
					mv /tmp/gfwlist.conf /koolshare/ss/rules/gfwlist.conf
					sed -i "1s/.*/$git_line1/" /koolshare/ss/rules/version
					reboot="1"
					echo_date 【更新成功】你的gfwlist已经更新到最新了哦~
				else
					echo_date 下载完成，但是校验没有通过！
				fi
			else
				echo_date 检测到gfwlist本地版本号和在线版本号相同，不进行更新!
			fi
		else
			echo_date gfwlist文件下载失败！
		fi
	else
		echo_date 然而你并没有勾选gfwlist更新！
	fi
	
	
	# update chnroute
	if [ "$ss_basic_chnroute_update" == "1" ];then
		echo_date " ------------------------------------------------------------------------"
		if [ ! -z "$version_chnroute2" ];then
			if [ "$version_chnroute1" != "$version_chnroute2" ];then
				echo_date 检测到新版本chnroute，开始更新...
				echo_date 下载chnroute到临时文件...
				wget --no-check-certificate --timeout=8 -qO - "$url_main"/chnroute.txt > /tmp/chnroute.txt
				md5sum_chnroute1=$(md5sum /tmp/chnroute.txt | sed 's/ /\n/g'| sed -n 1p)
				if [ "$md5sum_chnroute1"x = "$md5sum_chnroute2"x ];then
					echo_date 下载完成，校验通过，将临时文件覆盖到原始chnroute文件
					mv /tmp/chnroute.txt /koolshare/ss/rules/chnroute.txt
					sed -i "2s/.*/$git_line2/" /koolshare/ss/rules/version
					reboot="1"
					echo_date 【更新成功】你的chnroute已经更新到最新了哦~
				else
					echo_date md5sum 下载完成，但是校验没有通过！
				fi
			else
				echo_date 检测到chnroute本地版本号和在线版本号相同，不进行更新!
			fi
		else
			echo_date file chnroute文件下载失败！
		fi
	else
		echo_date 然而你并没有勾选chnroute更新！
	fi
	
	# update cdn file
	if [ "$ss_basic_cdn_update" == "1" ];then
		echo_date " ------------------------------------------------------------------------"
		if [ ! -z "$version_cdn2" ];then
			if [ "$version_cdn1" != "$version_cdn2" ];then
				echo_date 检测到新版本cdn名单，开始更新...
				echo_date 下载cdn名单到临时文件...
				wget --no-check-certificate --timeout=8 -qO - "$url_main"/cdn.txt > /tmp/cdn.txt
				md5sum_cdn1=$(md5sum /tmp/cdn.txt | sed 's/ /\n/g'| sed -n 1p)
				if [ "$md5sum_cdn1"x = "$md5sum_cdn2"x ];then
					echo_date 下载完成，校验通过，将临时文件覆盖到原始cdn名单文件
					mv /tmp/cdn.txt /koolshare/ss/rules/cdn.txt
					sed -i "4s/.*/$git_line4/" /koolshare/ss/rules/version
					reboot="1"
					echo_date 【更新成功】你的cdn名单已经更新到最新了哦~
				else
					echo_date 下载完成，但是校验没有通过！
				fi
			else
				echo_date 检测到cdn名单本地版本号和在线版本号相同，不进行更新!
			fi
		else
			echo_date file cdn名单文件下载失败！
		fi
	else
		echo_date 然而你并没有勾选cdn名单更新！
	fi
	
	
	# update pcap Routing file
	if [ "$ss_basic_pcap_update" == "1" ];then
		echo_date " ------------------------------------------------------------------------"
		if [ ! -z "$version_Routing2" ];then
			if [ "$version_Routing1" != "$version_Routing2" ];then
				echo_date 检测到新版本pcap Routing列表，开始更新...
				echo_date 下载pcap Routing名单到临时文件...
				wget --no-check-certificate --timeout=8 -qO - $url_main/Routing.txt > /tmp/Routing.txt
				md5sum_Routing1=$(md5sum /tmp/Routing.txt | sed 's/ /\n/g'| sed -n 1p)
				if [ "$md5sum_Routing1"x = "$md5sum_Routing2"x ];then
					echo_date 下载完成，校验通过，将临时文件覆盖到原始Routing名单文件
					mv /tmp/Routing.txt /koolshare/ss/rules/Routing.txt
					sed -i "5s/.*/$git_line5/" /koolshare/ss/rules/version
					reboot_pcap="1"
					echo_date 【更新成功】你的pcap Routing名单刚才已经更新到最新了哦~
				else
					echo_date 下载完成，但是校验没有通过！
				fi
			else
				echo_date 检测到pcap Routing名单本地版本号和在线版本号相同，那还更新个毛啊!
			fi
		else
			echo_date pcap Routing名单文件下载失败！
		fi
	else
		echo_date 然而你并没有勾选Pcap_list名单更新！
	fi
	
	# update pcap WhiteList file
	if [ "$ss_basic_pcap_update" == "1" ];then
		echo_date " ------------------------------------------------------------------------"
		if [ ! -z "$version_WhiteList2" ];then
			if [ "$version_WhiteList1" != "$version_WhiteList2" ];then
				echo_date 检测到新版本pcap WhiteList名单，开始更新...
				echo_date 下载pcap WhiteList名单到临时文件...
				wget --no-check-certificate --timeout=8 -qO - $url_main/WhiteList_new.txt > /tmp/WhiteList.txt
				md5sum_WhiteList1=$(md5sum /tmp/WhiteList.txt | sed 's/ /\n/g'| sed -n 1p)
				if [ "$md5sum_WhiteList1"x = "$md5sum_WhiteList2"x ];then
					echo_date 下载完成，校验通过，将临时文件覆盖到原始WhiteList名单文件
					mv /tmp/WhiteList.txt /koolshare/ss/rules/WhiteList.txt
					sed -i "7s/.*/$git_line7/" /koolshare/ss/rules/version
					reboot_pcap="1"
					echo_date 【更新成功】你的pcap WhiteList名单刚才已经更新到最新了哦~
				else
					echo_date 下载完成，但是校验没有通过！
				fi
			else
				echo_date 检测到pcap WhiteList名单本地版本号和在线版本号相同，那还更新个毛啊!
			fi
		else
			echo_date WhiteList名单文件下载失败！
		fi
	else
		echo_date 然而你并没有勾选Pcap_list名单更新！
	fi
	echo_date " ------------------------------------------------------------------------"
	rm -rf /tmp/gfwlist.conf1
	rm -rf /tmp/chnroute.txt1
	rm -rf /tmp/cdn.txt1
	rm -rf /tmp/version1
	
	echo_date Shadowsocks更新进程运行完毕！
	# write number
	nvram set update_ipset="$(cat /koolshare/ss/rules/version | sed -n 1p | sed 's/#/\n/g'| sed -n 1p)"
	nvram set update_chnroute="$(cat /koolshare/ss/rules/version | sed -n 2p | sed 's/#/\n/g'| sed -n 1p)"
	nvram set update_cdn="$(cat /koolshare/ss/rules/version | sed -n 4p | sed 's/#/\n/g'| sed -n 1p)"
	nvram set update_Routing="$(cat /koolshare/ss/rules/version | sed -n 5p | sed 's/#/\n/g'| sed -n 1p)"
	nvram set update_WhiteList="$(cat /koolshare/ss/rules/version | sed -n 7p | sed 's/#/\n/g'| sed -n 1p)"
	
	nvram set ipset_numbers=$(cat /koolshare/ss/rules/gfwlist.conf | grep -c ipset)
	nvram set chnroute_numbers=$(cat /koolshare/ss/rules/chnroute.txt | grep -c .)
	nvram set cdn_numbers=$(cat /koolshare/ss/rules/cdn.txt | grep -c .)
	nvram set Routing_numbers=$(cat /koolshare/ss/dns/Routing.txt |grep -c /)
	nvram set WhiteList_numbers=$(cat /koolshare/ss/dns/WhiteList.txt |grep -Ec "server=*")
	
	#======================================================================
	
	# reboot ss
	if [ "$reboot" == "1" ];then
		echo_date 自动重启shadowsocks，以应用新的规则文件！请稍后！
		sh /koolshare/ss/ssconfig.sh restart
	fi
	
	pcap=`pidof Pcap_DNSProxy`
	# reboot pcap
	if [ -z "$reboot" ] && [ -n "$pcap" ] && [ "$reboot_pcap" == "1" ];then
		echo_date 自动重启Pcap_DNSProxy，以应用新的规则文件！请稍后！
		killall Pcap_DNSProxy >/dev/null 2>&1
		Pcap_DNSProxy -c /koolshare/ss/dns
		echo_date 完成！
	fi	
	echo ==================================================================================================
}

change_cru(){
	echo ==================================================================================================
	sed -i '/ssupdate/d' /var/spool/cron/crontabs/* >/dev/null 2>&1
	if [ "1" == "$ss_basic_rule_update" ]; then
		echo_date 应用ss规则定时更新任务：每天"$ss_basic_rule_update_time"自动检测更新规则.
		cru a ssupdate "0 $ss_basic_rule_update_time * * * /bin/sh /koolshare/scripts/ss_rule_update.sh"
	else
		echo_date ss规则定时更新任务未启用！
	fi
}

if [ -z "$2" ];then
	#this is for autoupdate
	change_cru
	start_update
	dbus remove ss_basic_update_action
fi

case $2 in
1)
	echo " " > /tmp/upload/ss_log.txt
	http_response "$1"
	#svae only
	change_cru > /tmp/upload/ss_log.txt
	# incase next time auto update failed
	dbus remove ss_basic_update_action
	echo XU6J03M6 >> /tmp/upload/ss_log.txt
	;;
2)
	echo " " > /tmp/upload/ss_log.txt
	http_response "$1"
	#save and apply form we action
	ss_basic_gfwlist_update=1
	ss_basic_chnroute_update=1
	ss_basic_cdn_update=1
	ss_basic_pcap_update=1
	change_cru > /tmp/upload/ss_log.txt
	start_update >> /tmp/upload/ss_log.txt
	dbus remove 2
	echo XU6J03M6 >> /tmp/upload/ss_log.txt
	;;
esac

==> shadowsocks_1.0.5.tar.gz: shadowsocks/scripts/ss_rule_update.sh <==
#!/bin/sh

# shadowsocks script for koolshare merlin armv7l 384 router with kernel 2.6.36.4

source /koolshare/scripts/base.sh
eval $(dbus export ss_basic_)
alias echo_date='echo 【$(TZ=UTC-8 date -R +%Y年%m月%d日\ %X)】:'

start_update(){
	url_main="https://raw.githubusercontent.com/hq450/fancyss/master/rules"
	url_back=""
	# version dectet
	version_gfwlist1=$(cat /koolshare/ss/rules/version | sed -n 1p | sed 's/ /\n/g'| sed -n 1p)
	version_chnroute1=$(cat /koolshare/ss/rules/version | sed -n 2p | sed 's/ /\n/g'| sed -n 1p)
	version_cdn1=$(cat /koolshare/ss/rules/version | sed -n 4p | sed 's/ /\n/g'| sed -n 1p)
	
	echo ==================================================================================================
	echo_date 开始更新shadowsocks规则，请等待...
	wget --no-check-certificate --timeout=8 -qO - "$url_main"/version1 > /tmp/ss_version
	if [ "$?" == "0" ]; then
		echo_date 检测到在线版本文件，继续...
	else
		echo_date 没有检测到在线版本，可能是访问github有问题，去大陆白名单模式试试吧！
		rm -rf /tmp/ss_version
		exit
	fi
	
	online_content=$(cat /tmp/ss_version)
	if [ -z "$online_content" ];then
		rm -rf /tmp/ss_version
	fi
	
	git_line1=$(cat /tmp/ss_version | sed -n 1p)
	git_line2=$(cat /tmp/ss_version | sed -n 2p)
	git_line4=$(cat /tmp/ss_version | sed -n 4p)
	
	version_gfwlist2=$(echo $git_line1 | sed 's/ /\n/g'| sed -n 1p)
	version_chnroute2=$(echo $git_line2 | sed 's/ /\n/g'| sed -n 1p)
	version_cdn2=$(echo $git_line4 | sed 's/ /\n/g'| sed -n 1p)
	
	md5sum_gfwlist2=$(echo $git_line1 | sed 's/ /\n/g'| tail -n 2 | head -n 1)
	md5sum_chnroute2=$(echo $git_line2 | sed 's/ /\n/g'| tail -n 2 | head -n 1)
	md5sum_cdn2=$(echo $git_line4 | sed 's/ /\n/g'| tail -n 2 | head -n 1)
	
	# update gfwlist
	if [ "$ss_basic_gfwlist_update" == "1" ];then
		echo_date " --------------------------------------------------------------------"
		if [ ! -z "$version_gfwlist2" ];then
			if [ "$version_gfwlist1" != "$version_gfwlist2" ];then
				echo_date 检测到新版本gfwlist，开始更新...
				echo_date 下载gfwlist到临时文件...
				wget --no-check-certificate --timeout=8 -qO - "$url_main"/gfwlist.conf > /tmp/gfwlist.conf
				md5sum_gfwlist1=$(md5sum /tmp/gfwlist.conf | sed 's/ /\n/g'| sed -n 1p)
				if [ "$md5sum_gfwlist1"x = "$md5sum_gfwlist2"x ];then
					echo_date 下载完成，校验通过，将临时文件覆盖到原始gfwlist文件
					mv /tmp/gfwlist.conf /koolshare/ss/rules/gfwlist.conf
					sed -i "1s/.*/$git_line1/" /koolshare/ss/rules/version
					reboot="1"
					echo_date 【更新成功】你的gfwlist已经更新到最新！
				else
					echo_date 下载完成，但是校验没有通过！
				fi
			else
				echo_date 检测到gfwlist本地版本号和在线版本号相同，不进行更新!
			fi
		else
			echo_date gfwlist文件下载失败！
		fi
	else
		echo_date 然而你并没有勾选gfwlist更新！
	fi
	
	
	# update chnroute
	if [ "$ss_basic_chnroute_update" == "1" ];then
		echo_date " --------------------------------------------------------------------"
		if [ ! -z "$version_chnroute2" ];then
			if [ "$version_chnroute1" != "$version_chnroute2" ];then
				echo_date 检测到新版本chnroute，开始更新...
				echo_date 下载chnroute到临时文件...
				wget --no-check-certificate --timeout=8 -qO - "$url_main"/chnroute.txt > /tmp/chnroute.txt
				md5sum_chnroute1=$(md5sum /tmp/chnroute.txt | sed 's/ /\n/g'| sed -n 1p)
				if [ "$md5sum_chnroute1"x = "$md5sum_chnroute2"x ];then
					echo_date 下载完成，校验通过，将临时文件覆盖到原始chnroute文件
					mv /tmp/chnroute.txt /koolshare/ss/rules/chnroute.txt
					sed -i "2s/.*/$git_line2/" /koolshare/ss/rules/version
					reboot="1"
					echo_date 【更新成功】你的chnroute已经更新到最新！
				else
					echo_date md5sum 下载完成，但是校验没有通过！
				fi
			else
				echo_date 检测到chnroute本地版本号和在线版本号相同，不进行更新!
			fi
		else
			echo_date chnroute文件下载失败！
		fi
	else
		echo_date 然而你并没有勾选chnroute更新！
	fi
	
	# update cdn file
	if [ "$ss_basic_cdn_update" == "1" ];then
		echo_date " --------------------------------------------------------------------"
		if [ ! -z "$version_cdn2" ];then
			if [ "$version_cdn1" != "$version_cdn2" ];then
				echo_date 检测到新版本cdn名单，开始更新...
				echo_date 下载cdn名单到临时文件...
				wget --no-check-certificate --timeout=8 -qO - "$url_main"/cdn.txt > /tmp/cdn.txt
				md5sum_cdn1=$(md5sum /tmp/cdn.txt | sed 's/ /\n/g'| sed -n 1p)
				if [ "$md5sum_cdn1"x = "$md5sum_cdn2"x ];then
					echo_date 下载完成，校验通过，将临时文件覆盖到原始cdn名单文件
					mv /tmp/cdn.txt /koolshare/ss/rules/cdn.txt
					sed -i "4s/.*/$git_line4/" /koolshare/ss/rules/version
					reboot="1"
					echo_date 【更新成功】你的cdn名单已经更新到最新！
				else
					echo_date 下载完成，但是校验没有通过！
				fi
			else
				echo_date 检测到cdn名单本地版本号和在线版本号相同，不进行更新!
			fi
		else
			echo_date cdn名单文件下载失败！
		fi
	else
		echo_date 然而你并没有勾选cdn名单更新！
	fi
	echo_date " --------------------------------------------------------------------"
	rm -rf /tmp/gfwlist.conf1
	rm -rf /tmp/chnroute.txt1
	rm -rf /tmp/cdn.txt1
	rm -rf /tmp/ss_version
	
	echo_date Shadowsocks更新进程运行完毕！
	# write number
	nvram set update_ipset="$(cat /koolshare/ss/rules/version | sed -n 1p | sed 's/#/\n/g'| sed -n 1p)"
	nvram set update_chnroute="$(cat /koolshare/ss/rules/version | sed -n 2p | sed 's/#/\n/g'| sed -n 1p)"
	nvram set update_cdn="$(cat /koolshare/ss/rules/version | sed -n 4p | sed 's/#/\n/g'| sed -n 1p)"
	
	nvram set ipset_numbers=$(cat /koolshare/ss/rules/gfwlist.conf | grep -c ipset)
	nvram set chnroute_numbers=$(cat /koolshare/ss/rules/chnroute.txt | grep -c .)
	nvram set chnroute_ips=$(awk -F "/" '{sum += 2^(32-$2)};END {print sum}' /koolshare/ss/rules/chnroute.txt)
	nvram set cdn_numbers=$(cat /koolshare/ss/rules/cdn.txt | grep -c .)
	#======================================================================
	# reboot ss
	if [ "$reboot" == "1" ];then
		echo_date 自动重启shadowsocks，以应用新的规则文件！请稍后！
		sh /koolshare/ss/ssconfig.sh restart
	fi
	echo ==================================================================================================
}

change_cru(){
	echo ==================================================================================================
	sed -i '/ssupdate/d' /var/spool/cron/crontabs/* >/dev/null 2>&1
	if [ "1" == "$ss_basic_rule_update" ]; then
		echo_date 应用ss规则定时更新任务：每天"$ss_basic_rule_update_time"自动检测更新规则.
		cru a ssupdate "0 $ss_basic_rule_update_time * * * /bin/sh /koolshare/scripts/ss_rule_update.sh"
	else
		echo_date ss规则定时更新任务未启用！
	fi
}

if [ -z "$2" ];then
	#this is for autoupdate
	change_cru
	start_update
fi

case $2 in
1)
	echo " " > /tmp/upload/ss_log.txt
	http_response "$1"
	change_cru > /tmp/upload/ss_log.txt
	echo XU6J03M6 >> /tmp/upload/ss_log.txt
	;;
2)
	echo " " > /tmp/upload/ss_log.txt
	http_response "$1"
	ss_basic_gfwlist_update=1
	ss_basic_chnroute_update=1
	ss_basic_cdn_update=1
	change_cru > /tmp/upload/ss_log.txt
	start_update >> /tmp/upload/ss_log.txt
	dbus remove 2
	echo XU6J03M6 >> /tmp/upload/ss_log.txt
	;;
esac
